@@ -102,9 +102,7 @@ class SICard():
         if num < 500000:
             # SI Card 5
             num2 = bytes_to_int(data[2:4])
-            if data[1] < 2:
-                return num2
-            return data[1]*100000 + num
+            return data[1]*100000 + num2
         return num
 
     @property
@@ -207,12 +205,35 @@ class SICard():
                     punch_date = data[punch_pointer + self.PTD]
                     punch_control += (punch_date << 2) & ~0xFF
 
-                self._punches.append(Punch.from_bytes(punch_control, punch_time, punch_date, reftime))
+                self.add_punch(Punch.from_bytes(punch_control, punch_time, punch_date, reftime))
 
     def process_extra_data(self, data: bytes):
         """process any non standard data from the SICard read out"""
         raise NotImplementedError
 
+    @classmethod
+    def from_auto_send(cls, data: bytes, station: 'SiUSBStation'):
+        """create a SI Card object from the data send with auto send."""
+        control_number = bytes_to_int(data[:2])
+        si_number = cls.decode_number(data[2:6])
+        time = cls.decode_time(data[7:10], data[6])
+        # mem_pointer = bytes_to_int(data[10:])
+        card: SICard
+        if si_number <= 499999:
+            card = SI5(data[2:6], station)
+        elif 500000 <= si_number <= 999999 or (2003000 <= si_number <= 2003999):
+            card = SI6(data[2:6], station)
+        else:
+            card = SI8To10.switch_types(data[2:6], station)
+        card.add_punch(Punch(control_number, time))
+        return card
+
+    def add_punch(self, punch: Punch):
+        """adds a punch to the list of punches"""
+        if not self.punches:
+            self._punches = []
+        self._punches.append(punch)
+
     @classmethod
     def decode_time(cls, raw_time: bytes, punchdate: int = None, reftime: 'datetime' = None) -> 'Optional[datetime]':
         """decode date and time from bytes before reftime"""
@@ -312,7 +333,7 @@ class SI5(SICard):
         if punch_count > self.PM:
             punch_count = self.PM
         punch_pointer = self.P1
-        for punch_counter in range(punch_count): # pylint: disable=unused-variable
+        for _ in range(punch_count):
             if punch_pointer % 16 == 0:
                 # first byte of each block is reserved for punches 31 - 36
                 if data[punch_pointer]:
@@ -323,7 +344,7 @@ class SI5(SICard):
             punch_time = data[punch_pointer + self.PTH:punch_pointer + self.PTL + 1]
             punch_date = data[punch_pointer + self.PTD] if self.PTD != -1 else None
 
-            self._punches.append(Punch.from_bytes(punch_control, punch_time, punch_date, reftime))
+            self.add_punch(Punch.from_bytes(punch_control, punch_time, punch_date, reftime))
             punch_pointer += self.PL
         self.punches.extend(no_time_punches)
 
@@ -385,7 +406,7 @@ class SI6(SICard):
             raise SiError("Can't read Si-Card!")
         raw_data = ret.data[3:]
 
-        for i in range(2): # pylint: disable=unused-variable
+        for _ in range(2):
             ret2 = self._station.receive_command()
             if not isinstance(ret2, Command):
                 raise SiError("Can't read Si-Card!")
@@ -414,7 +435,7 @@ class SI6(SICard):
                 punch_time = raw_data[punch_pointer + self.PTH:punch_pointer + self.PTL + 1]
                 punch_date = raw_data[punch_pointer + self.PTD] if self.PTD != -1 else None
 
-                self._punches.append(Punch.from_bytes(punch_control, punch_time, punch_date, reftime))
+                self.add_punch(Punch.from_bytes(punch_control, punch_time, punch_date, reftime))
                 punch_pointer += self.PL
 
     def process_extra_data(self, data: bytes):
