@@ -36,7 +36,7 @@ def compute_crc(data: Union[bytes, List[int]]) -> 'int':
             else:
                 ui_val = 0
 
-        for j in range(16): # pylint: disable=unused-variable
+        for _ in range(16):
             if ui_tmp1 & 0x8000:
                 ui_tmp1 <<= 1
                 ui_tmp1 &= 0x0000FFFF
